/** @jsx jsx */
import { jsx, css } from '@emotion/core';
import * as React from 'react';

import Nav from './Nav';
import Sidebar from './Sidebar';
import { RouteComponentProps, Redirect } from '@reach/router';

import { useAccountValue } from '../hooks/useAccount';

const Main: React.FC<
  RouteComponentProps | { children: React.ReactNode }
> = props => {
  const { children } = props;
  const { account } = useAccountValue();
  if (!account) return <Redirect to="login" noThrow />;
  return (
    <main
      css={css`
        display: flex;
        justify-content: space-between;
        padding: 0;
      `}
    >
      <Sidebar />
      <section
        css={css`
          flex: 1;
          padding-top: 64px;
        `}
      >
        <div>
          <Nav />
          <div
            css={css`
              padding: 0 1.5rem;
            `}
          >
            <div
              css={css`
                padding: 1.5rem 0;
              `}
            >
              {children}
            </div>
          </div>
        </div>
      </section>
    </main>
  );
};

export default React.memo(Main);
